@@ -24,6 +24,8 @@ class Client:
     marqo and its permissions.
     """
 
+
+
     def __init__(
         self, url: str = "http://localhost:9200", main_user: str = None, main_password: str = None,
         indexing_device: Optional[Union[enums.Devices, str]] = None,
@@ -46,6 +48,16 @@ class Client:
         self.config = Config(self.url, indexing_device=indexing_device, search_device=search_device)
         self.http = HttpRequests(self.config)
         index_meta_cache.populate_cache(config=self.config)
+        self._turn_off_auto_create_index()
+
+    def _turn_off_auto_create_index(self):
+        """turns off auto creation of indices. To be run in client instantiation"""
+        self.http.put(
+            path="_cluster/settings",
+            body={
+                "persistent": {"action.auto_create_index": "false"}
+            })
+
 
     def create_index(
         self, index_name: str,
